post_process_css

Function post_process_css 

pub fn post_process_css(
    raw_rules: &[(String, CssProps)],
    vars: &IndexMap<String, String>,
) -> String
Flatten CSS with potential selectors that include media prelude. This simple post-processor merges entries that use the special selector format “@media (min-width: X) {” where we will close the block at the end. We group by media and inside concatenate selectors.