Crate themed_styler

Crate themed_styler 

Modules

api

Structs

State
ThemeEntry

Enums

Error

Functions

post_process_css
Flatten CSS with potential selectors that include media prelude. This simple post-processor merges entries that use the special selector format “@media (min-width: X) {” where we will close the block at the end. We group by media and inside concatenate selectors.
themed_styler_free_string
themed_styler_render_css
themed_styler_version
version

Type Aliases

CssProps
SelectorStyles